==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Form/CreateMWDatabase.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class CreateMWDatabase extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $roles;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, MWConfigBuilder $mw_config_builder, ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'create_mw_database';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $database_fields = ['id', 'key', 'target', 'host', 'database', 'username', 'password', 'prefix', 'driver', 'port', 'namespace', 'collation', 'url_files_prod'];
    $form['use_env'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use .env')
    ];
    foreach($database_fields as $database_field){
      $form[$database_field] = [
        '#type' => 'textfield',
        '#title' => t($database_field),
        '#size' => '20',
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $user_inputs = $form_state->getUserInput();
    $migrate_wizard_settings = $this->config->get('migrate_wizard_settings');
    if(isset($migrate_wizard_settings['databases']) && isset($migrate_wizard_settings['databases'][$user_inputs["id"]])){
      $form_state->setErrorByName('id', t('Database configuration already exists'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $user_inputs = $form_state->getUserInput();
    $migrate_wizard_settings = $this->config->get('migrate_wizard_settings');
    if(!isset($migrate_wizard_settings['databases']) || !isset($migrate_wizard_settings['databases'][$user_inputs["id"]])){
      $this->entityTypeManager->getStorage('mw_database')->create($user_inputs)->save();
      $migrate_wizard_settings['databases'][$user_inputs["id"]] = ['host' => $user_inputs['host'], 'database' => $user_inputs['database'], 'username' => $user_inputs['username'], 'password' => $user_inputs['password']];
      $this->config->set('migrate_wizard_settings', $migrate_wizard_settings)->save();
      $form_state->setRedirect('entity.database.list');
    }
  }

  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    return $this->t('Create MW Database');
  }
}

==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Form/CreateMWDatabase.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class CreateMWDatabase extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $roles;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, MWConfigBuilder $mw_config_builder, ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'create_mw_database';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $database_fields = ['id', 'migration_group', 'key', 'target', 'host', 'database', 'username', 'password', 'prefix', 'driver', 'port', 'namespace', 'collation', 'url_files_prod'];
    $form['use_env'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use .env')
    ];
    foreach($database_fields as $database_field){
      $form[$database_field] = [
        '#type' => 'textfield',
        '#title' => t($database_field),
        '#size' => '20',
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $user_inputs = $form_state->getUserInput();
    $migrate_wizard_settings = $this->config->get('migrate_wizard_settings');
    if(isset($migrate_wizard_settings['databases']) && isset($migrate_wizard_settings['databases'][$user_inputs["id"]])){
      $form_state->setErrorByName('id', t('Database configuration already exists'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $user_inputs = $form_state->getUserInput();
    $migrate_wizard_settings = $this->config->get('migrate_wizard_settings');
    if(!isset($migrate_wizard_settings['databases']) || !isset($migrate_wizard_settings['databases'][$user_inputs["id"]])){
      $this->entityTypeManager->getStorage('mw_database')->create($user_inputs)->save();
      $migrate_wizard_settings['databases'][$user_inputs["id"]] = ['host' => $user_inputs['host'], 'database' => $user_inputs['database'], 'username' => $user_inputs['username'], 'password' => $user_inputs['password']];
      $this->config->set('migrate_wizard_settings', $migrate_wizard_settings)->save();
      $form_state->setRedirect('entity.database.list');
    }
  }

  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    return $this->t('Create MW Database');
  }
}
